==> kernel-2.0.14.1-sources.jar: com/voxeet/sdk/core/impl/ConferenceSdkService.java <==
package com.voxeet.sdk.core.impl;

import eu.codlab.simplepromise.Promise;

import com.voxeet.sdk.json.UserInfo;
import com.voxeet.sdk.core.VoxeetSdkTemplate;
import com.voxeet.sdk.core.abs.AbstractConferenceSdkService;
import com.voxeet.sdk.core.network.ISdkConferenceRService;
import com.voxeet.sdk.core.services.holder.ServiceProviderHolder;
import com.voxeet.sdk.events.success.ConferenceCreationSuccess;
import com.voxeet.sdk.models.ConferenceResponse;
import com.voxeet.sdk.models.ConferenceType;
import com.voxeet.sdk.models.impl.DefaultConference;
import com.voxeet.sdk.models.impl.DefaultConferenceUser;

/**
 * Created by kevinleperf on 13/11/2017.
 */

public class ConferenceSdkService extends AbstractConferenceSdkService<ISdkConferenceRService, ConferenceSdkObservableProvider> {

    public ConferenceSdkService(VoxeetSdkTemplate instance, long timeout) {
        super(instance, new ConferenceSdkObservableProvider(), timeout,
                new ServiceProviderHolder.Builder<ISdkConferenceRService>()
                        .setRetrofit(instance.getRetrofit())
                        .setService(ISdkConferenceRService.class)
                        .setEventBus(instance.getEventBus())
                        .setClient(instance.getClient())
                        .build());
    }

    @Override
    protected Promise<Boolean> onCreateDemoSuccess(ConferenceResponse response) {
        DefaultConference conference = createConference();
        conference.setConferenceId(response.getConfId());
        conference.setConferenceType(ConferenceType.DEMO.value());

        String conferenceAlias = response.getConfAlias();

        setConference(conference);
        setConferenceAlias(conferenceAlias);

        getTwig().i("Demo conference created with id: " + conference.getConferenceId());

        getEventBus().post(new ConferenceCreationSuccess(response.getConfId(), response.getConfAlias()));

        return joinVoxeetConference(response.getConfId());
    }

    @Override
    protected DefaultConference createConference() {
        return new DefaultConference();
    }

    @Override
    protected DefaultConferenceUser createConferenceUser(String userId, String device, UserInfo userInfo) {
        return new DefaultConferenceUser(userId, device, userInfo);
    }

    @Override
    protected UserInfo createUserInfo(String userName, String externalId, String avatarUrl) {
        return new UserInfo(userName, externalId, avatarUrl);
    }

    @Override
    protected void startTransactionConferenceUser() {
        //starting transaction
    }

    @Override
    protected void commitTransactionConferenceUser() {
        //commiting transaction
    }

    /**
     * Return true; some methods will have a behaviour slightly different
     *
     * @return the state of this implementation
     */
    @Override
    protected boolean isSDK() {
        return true;
    }

    @Override
    public Promise<Boolean> onCreationSuccess(String conferenceId) {
        return joinVoxeetConference(conferenceId);
    }
}

==> kernel-2.0.16-sources.jar: com/voxeet/sdk/core/impl/ConferenceSdkService.java <==
package com.voxeet.sdk.core.impl;

import eu.codlab.simplepromise.Promise;

import com.voxeet.sdk.json.UserInfo;
import com.voxeet.sdk.core.VoxeetSdkTemplate;
import com.voxeet.sdk.core.abs.AbstractConferenceSdkService;
import com.voxeet.sdk.core.network.ISdkConferenceRService;
import com.voxeet.sdk.core.services.holder.ServiceProviderHolder;
import com.voxeet.sdk.events.success.ConferenceCreationSuccess;
import com.voxeet.sdk.models.ConferenceResponse;
import com.voxeet.sdk.models.ConferenceType;
import com.voxeet.sdk.models.abs.Conference;
import com.voxeet.sdk.models.abs.ConferenceUser;

public class ConferenceSdkService extends AbstractConferenceSdkService<ISdkConferenceRService, ConferenceSdkObservableProvider> {

    public ConferenceSdkService(VoxeetSdkTemplate instance, long timeout) {
        super(instance, new ConferenceSdkObservableProvider(), timeout,
                new ServiceProviderHolder.Builder<ISdkConferenceRService>()
                        .setRetrofit(instance.getRetrofit())
                        .setService(ISdkConferenceRService.class)
                        .setEventBus(instance.getEventBus())
                        .setClient(instance.getClient())
                        .build());
    }

    @Override
    protected Promise<Boolean> onCreateDemoSuccess(ConferenceResponse response) {
        Conference conference = createConference();
        conference.setConferenceId(response.getConfId());
        conference.setConferenceType(ConferenceType.DEMO.value());

        String conferenceAlias = response.getConfAlias();

        setConference(conference);
        setConferenceAlias(conferenceAlias);

        getTwig().i("Demo conference created with id: " + conference.getConferenceId());

        getEventBus().post(new ConferenceCreationSuccess(response.getConfId(), response.getConfAlias()));

        return joinVoxeetConference(response.getConfId());
    }

    @Override
    protected Conference createConference() {
        return new Conference();
    }

    @Override
    protected ConferenceUser createConferenceUser(String userId, String device, UserInfo userInfo) {
        return new ConferenceUser(userId, device, userInfo);
    }

    @Override
    protected UserInfo createUserInfo(String userName, String externalId, String avatarUrl) {
        return new UserInfo(userName, externalId, avatarUrl);
    }

    @Override
    protected void startTransactionConferenceUser() {
        //starting transaction
    }

    @Override
    protected void commitTransactionConferenceUser() {
        //commiting transaction
    }

    /**
     * Return true; some methods will have a behaviour slightly different
     *
     * @return the state of this implementation
     */
    @Override
    protected boolean isSDK() {
        return true;
    }

    @Override
    public Promise<Boolean> onCreationSuccess(String conferenceId) {
        return joinVoxeetConference(conferenceId);
    }
}
